"""
pylaxz

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Copyright (c) 2020 Min Latt.
License: MIT, see LICENSE for more details.

A small utility for my personal use cases.
"""

from .utils.logxs import printf
from .__version__ import version
from . import orm